@@ -78,7 +78,7 @@ int expose;
 int vtot, vcur, pos, ftheight; /* global variables for scrollbar */
 
 int Width, Height;
-int fwidth, fheight;	/* font character width, height */
+int fwidth, fheight, ycur = 0;	/* font character width, height */
 
 /* Foreground, Background normal and highlight colores */
 XColor FgXColor, BgXColor, CrXColor, 
@@ -327,13 +327,15 @@ void show_vbar()
 	lowvideo();
 }
 
-void scroll_text(int ycur)
+void scroll_text()
 {
-	int m, newy, rep;
+	int m, rep;
 
-	m = ycur - ftheight;
-	newy = (m*ytot)/vtot;
-	rep = 1+abs(ytru-newy)/screen_height;
+        if (ycur<0) { y=0 ; scroll_down(); ycur = 0; }
+        if (ycur>ytot) ycur = ytot;
+
+        m = (ycur * vtot) / (ytot? ytot : 1);
+	rep = abs(ytru-ycur)/screen_height;
 
 	if(m<0) scroll_down();					/* if cursor at top of screen */
 	else if(m>vtot+ftheight) scroll_up();	/* if cursor at bottom of screen */
@@ -345,7 +347,8 @@ void scroll_text(int ycur)
 	     for (m=0; m<rep; m++)
 	         cursor_pagedown();	/* if cursor below thumb */
 	}
-	else goto_y(newy);	/* else cursor on thumb so track it */
+
+	goto_y(ycur);  /* cursor on thumb so track it */
 
 	scr_update(); /* does show_vbar */
 }
@@ -360,7 +363,7 @@ void update()
 		if (executive == DIALOG) {
 			undraw_cursor();
 			show_gets(comment, diabuf, dblen, dialogCB);
-			gotoxy(diastart+col,y1);
+			gotoxy(diastart+col,yl1);
 			draw_cursor();
 		}
 }
@@ -768,7 +771,7 @@ void handle_key(char *astr, int skey, int state)
 
 		/* display keyboard shift/control/alt status */
 		highvideo();
-		gotoxy(0,y1);
+		gotoxy(0,yl1);
 		for(n=5;n;chstr[n--]=' ');
 		if(state & ShiftMask) chstr[n++] = 'S';
 		if(state & Mod1Mask) chstr[n++] = 'A';
@@ -843,7 +846,7 @@ int main(int argc,char *argv[])
 {
 	Atom WM_PROTOCOLS = 0;
 	struct sigaction sig;
-	int y0 = 0, y1 = 0, yf, yt;
+	int yp0 = 0, yp1 = 0, yf, yt;
 
 	init(argc,argv);
 
@@ -896,8 +899,11 @@ int main(int argc,char *argv[])
 				break;
 			case MotionNotify:
 				if (buttonpressed==-1) {
-				        if (executive == MAIN)
-						scroll_text(event.xbutton.y);
+				        if (executive == MAIN) {
+					   ycur = 
+				     ((event.xbutton.y - ftheight)*ytot)/vtot;
+					   scroll_text();
+					}
 					break;
 				}
 #ifndef TWOBUTN
@@ -935,12 +941,12 @@ int main(int argc,char *argv[])
 						if (yf) goto finish;
 #endif
 						moveto();
-						yf = y0;
+						yf = yp0;
 						if (y<yf) yf = y;
-						if (y1<yf) yf = y1;
-						yt = y0;
+						if (yp1<yf) yf = yp1;
+						yt = yp0;
 						if (y>yt) yt = y;
-						if (y1>yt) yt = y1;
+						if (yp1>yt) yt = yp1;
 						show_scr(yf, yt);
 #ifndef TWOBUTN
 					finish:
@@ -949,11 +955,23 @@ int main(int argc,char *argv[])
 						cur_pos = get_cur();
 						gotoxy(x-1,y+1);
 						draw_cursor();
-						y1 = y;
+						yp1 = y;
 					}
 				}
 				break;
 			case ButtonPress:
+				if (event.xbutton.button>Button3 &&
+				    executive==MAIN) {
+				   if (event.xbutton.button==Button4) {
+				      ycur -= 3;
+				      scroll_text();
+				   }
+				   if (event.xbutton.button==Button5) {
+				      ycur += 3;
+				      scroll_text();
+				   }
+				   break;
+				}
 				help_done = 0;
 				undraw_cursor();
 			        if (event.xbutton.x>=Width-10) {
@@ -973,7 +991,7 @@ int main(int argc,char *argv[])
 				if (event.xbutton.time - eve_time < DBLCLICK) break;
 				eve_time = event.xbutton.time;
 				moveto();
-				y0 = y;
+				yp0 = y;
 				flag[SHW] = 1;
 				cur_pos = get_cur();
 				if (flag[BLK]) {
@@ -1081,6 +1099,3 @@ int main(int argc,char *argv[])
 
 	}
 }
-
-
-
